@@ -1,4 +1,8 @@
 <?php
+$lang['dflt_urlprefix'] = 'Voreingestelltes URL-Pr&auml;fix f&uuml;r Pretty URLs';
+$lang['dflt_alldayevent'] = 'Neue Termine sollen voreingestellt ganzt&auml;gig sein';
+$lang['dflt_starttime'] = 'Voreingestellte Startzeit f&uuml;r neue Termine';
+$lang['info_dflt_starttime'] = '<em>(wird nur dann angewendet, wenn neue Termine keine ganzt&auml;tigen Termine sind.)</em>';
 $lang['search_type'] = 'Such-Typ';
 $lang['search_any'] = 'Gibt Ergebnisse zur&uuml;ck, wenn irgend ein Wort enthalten ist';
 $lang['search_all'] = 'Gibt Ergebnisse zur&uuml;ck, wenn alle Worte enthalten sind';
@@ -16,24 +20,24 @@ $lang['prompt_feedit_group'] = 'Mitglieder dieser FEU-Gruppe d&uuml;rfen Termine
 $lang['prompt_feedit_page'] = 'Voreingestellte Seite f&uuml;r das Bearbeitungsformular auf der Webseite/Frontend';
 $lang['none'] = 'Kein(e)/ohne Vorgabe';
 $lang['owner'] = 'Eigent&uuml;mer';
-$lang['cal_editevent_templates'] = 'Edit Event Form Templates';
-$lang['info_editevent_template_tab'] = 'The list of templates that are available for the edit event form';
-$lang['editeventtemplate_addedit'] = 'Add/Edit an Edit Event Form Template';
-$lang['cal_myevents_templates'] = 'My Events List Templates';
-$lang['info_myevents_template_tab'] = 'The list of templates that are available to display a list of user events';
-$lang['myeventstemplate_addedit'] = 'Add/Edit a &quot;My Events&quot; report template';
-$lang['areyousure_removeconflicting'] = 'This action will remove any events that conflict with non-overlappable events.  Are you sure you want to do this?';
-$lang['filter_conflicting'] = 'Filter Conflicting Events';
-$lang['overlap_action_remove'] = 'Silently remove conflicting events';
+$lang['cal_editevent_templates'] = 'Templates zum Bearbeiten von Termin-Formularen';
+$lang['info_editevent_template_tab'] = 'Die Liste der Templates, die f&uuml;r die Bearbeitung von Termin-Formularen verf&uuml;gbar sind';
+$lang['editeventtemplate_addedit'] = 'Ein Template zum Bearbeiten von Termin-Formularen hinzuf&uuml;gen/bearbeiten';
+$lang['cal_myevents_templates'] = 'Meine Termin-Listen-Templates';
+$lang['info_myevents_template_tab'] = 'Die Liste der Templates, die f&uuml;r die Anzeige einer Liste von Benutzerterminen verf&uuml;gbar sind';
+$lang['myeventstemplate_addedit'] = 'Ein &quot;Meine Termine&quot;-Berichts-Template hinzuf&uuml;gen/bearbeiten';
+$lang['areyousure_removeconflicting'] = 'Mit dieser Aktion werden alle Termine entfernt, die Konflikte mit Terminen hervorrufen, die nicht von anderen Terminen &uuml;berlappt werden d&uuml;rfen. Wollen Sie das wirklich?';
+$lang['filter_conflicting'] = 'Konfliktbehaftete Termine filtern';
+$lang['overlap_action_remove'] = 'Konfliktbehaftete Termine still entfernen';
 $lang['overlap_action_error'] = 'Einen Fehler anzeigen';
 $lang['prompt_overlap_action'] = 'Was soll passieren, wenn ein Konflikt beim Erstellen oder Bearbeiten eines Termins festgestellt wird?';
-$lang['error_event_conflict'] = 'The event values specified overlap with an existing event that does not allow conflicts';
-$lang['cal_info_overlap'] = 'Nur auf Termine mit einer Endzeit oder Ganztagsereignisse anwenden';
+$lang['error_event_conflict'] = 'Die f&uuml;r den Termin eingegebenen Werte &uuml;berschneiden sich mit einem bereits existierenden Termin, der nicht &uuml;berlappt werden darf';
+$lang['cal_info_overlap'] = 'Nur auf Termine mit einer Endzeit oder ganzt&auml;gigen Terminen anwenden';
 $lang['cal_overlap'] = 'Neuen Terminen erlauben, sich mit diesen zu &uuml;berschneiden';
-$lang['prompt_overlap_policy'] = 'Event Overlap Policy';
+$lang['prompt_overlap_policy'] = 'Regel f&uuml;r Termin&uuml;berschneidungen';
 $lang['policy_all'] = 'Alle Termine k&ouml;nnen sich &uuml;berschneiden';
 $lang['policy_none'] = 'Kein Termin darf sich &uuml;berschneiden';
-$lang['policy_individual'] = 'Decided on an event by event basis';
+$lang['policy_individual'] = 'Soll f&uuml;r jeden Termin individuell festgelegt werden k&ouml;nnen';
 $lang['lbl_back'] = 'Zur&uuml;ck';
 $lang['lbl_templates'] = 'Templates ';
 $lang['textarea'] = 'Textbereich';
@@ -85,8 +89,8 @@ $lang['last_thursday'] = 'Letzter Donnerstag des Monats';
 $lang['last_friday'] = 'Letzter Freitag des Monats';
 $lang['last_saturday'] = 'Letzter Samstag des Monats';
 $lang['error_invalid_recur_monthly_freq'] = 'Ung&uuml;ltige Wiederholung &ndash; ein bestimmtes Datum kann nicht zusammen mit anderen Werten angegeben werden';
-$lang['searchresulttemplate_addedit'] = 'Hinzuf&uuml;gen/Bearbeiten eines Suchergebnis-Templates';
-$lang['info_searchresult_template_tab'] = 'Eine Liste der verf&uuml;gbaren Templates f&uuml;r die Anzeige der Suchergebnisse';
+$lang['searchresulttemplate_addedit'] = 'Ein Suchergebnis-Template hinzuf&uuml;gen/bearbeiten';
+$lang['info_searchresult_template_tab'] = 'Eine Liste der Templates, die f&uuml;r die Anzeige der Suchergebnisse verf&uuml;gbar sind';
 $lang['info_sysdflt_searchresult_template'] = 'Voreingestelltes Template f&uuml;r Suchergebnis';
 $lang['cal_search_result_templates'] = 'Templates f&uuml;r Suchergebnisse';
 $lang['error_query_failed'] = 'Datenbankabfrage fehlgeschlagen';
@@ -96,7 +100,7 @@ $lang['search'] = 'Suche';
 $lang['category'] = 'Kategorie';
 $lang['info_sysdflt_search_template'] = 'Voreingestelltes Suchformular-Template';
 $lang['searchtemplate_addedit'] = 'Ein Suchformular-Template hinzuf&uuml;gen/bearbeiten';
-$lang['info_search_template_tab'] = 'Liste der verf&uuml;gbaren Templates f&uuml;r die Anzeige des Suchformulars';
+$lang['info_search_template_tab'] = 'Liste der Templates, die f&uuml;r die Anzeige des Suchformulars verf&uuml;gbar sind';
 $lang['cal_search_form_templates'] = 'Suchformular-Templates';
 $lang['max'] = 'maximal';
 $lang['times'] = 'Mal';
@@ -140,7 +144,7 @@ $lang['interval'] = 'Wiederholung';
 $lang['cal_recur_details'] = 'Details zu wiederkehrenden Terminen';
 $lang['unlimited'] = 'Unbeschr&auml;nkt';
 $lang['max_recur_events'] = 'Maximale Anzahl von untergeordneten Terminen';
-$lang['use_to_date'] = 'Wollen Sie ein abweichendes Enddatum eingeben?';
+$lang['use_to_date'] = 'M&ouml;chten Sie ein abweichendes Enddatum eingeben?';
 $lang['cancel'] = 'Abbrechen';
 $lang['show_child_events'] = 'Untergeordnete Termine anzeigen <em>(das Ergebnis kann eine sehr lange Liste sein)</em>';
 $lang['n/a'] = 'keine Angabe';
@@ -152,7 +156,7 @@ $lang['start_date'] = 'Startdatum';
 $lang['end_date'] = 'Enddatum';
 $lang['info_upcominglist_template_tab'] = 'Liste der Templates, die f&uuml;r die Anzeige der Liste f&uuml;r zuk&uuml;nftige Termine verf&uuml;gbar sind';
 $lang['upcominglisttemplate_addedit'] = 'Ein Template f&uuml;r die Anzeige einer Liste mit zuk&uuml;nftigen Terminen hinzuf&uuml;gen/bearbeiten';
-$lang['info_sysdflt_upcominglist_template'] = 'Standard-Template f&uuml;r k&uuml;nftige Ereignisse';
+$lang['info_sysdflt_upcominglist_template'] = 'Standard-Template f&uuml;r zuk&uuml;nftige Ereignisse';
 $lang['info_list_template_tab'] = 'Die Liste der Templates, die f&uuml;r die Anzeige der Liste f&uuml;r Ereignisse verf&uuml;gbar sind';
 $lang['listtemplate_addedit'] = 'Ein Template f&uuml;r die Anzeige von Listen hinzuf&uuml;gen/bearbeiten';
 $lang['info_sysdflt_list_template'] = 'Standard-Listen-Template';
@@ -162,7 +166,7 @@ $lang['info_sysdflt_event_template'] = 'Standard-Ereignis-Template';
 $lang['info_calendar_template_tab'] = 'Die Liste der Templates, die f&uuml;r die Anzeige des Kalenders bereit stehen';
 $lang['calendartemplate_addedit'] = 'Ein Template f&uuml;r die Anzeige eines Kalenders hinzuf&uuml;gen/bearbeiten';
 $lang['info_sysdflt_calendar_template'] = 'Standard-Kalender-Template';
-$lang['info_sysdflt_template'] = 'In diesem Formular k&ouml;nnen Templates definiert werden, die dann eingef&uuml;gt werden, wenn Sie in der entsprechenden Registerkarte auf &bdquo;Neues Template&ldquo; klicken. Hier vorgenommene &Auml;nderungen haben keine direkte Auswirkungen auf die Ausgabe dieses Moduls.';
+$lang['info_sysdflt_template'] = 'In diesem Formular k&ouml;nnen Templates festgelegt werden, die dann eingef&uuml;gt werden, wenn Sie in der jeweiligen Registerkarte auf &bdquo;Neues Template&ldquo; klicken. Hier vorgenommene &Auml;nderungen haben keine direkte Auswirkungen auf die Ausgabe dieses Moduls.';
 $lang['eventdesc-EventAdded'] = 'Ausf&uuml;hren, nachdem ein Termin hinzuf&uuml;gt wurde';
 $lang['eventdesc-EventEdited'] = 'Ausf&uuml;hren, nachdem ein Termin bearbeitet wurde';
 $lang['eventdesc-EventDeleted'] = 'Ausf&uuml;hren, nachdem ein Termin gel&ouml;scht wurde';
@@ -223,7 +227,7 @@ $lang['eventhelp-CategoryDeleted'] = '<p>Ausf&uuml;hren, wenn eine Kalender-Kate
 ';
 $lang['msg_eventadded'] = 'Termin hinzugef&uuml;gt';
 $lang['error_noeventname'] = 'Sie m&uuml;ssen einen Namen f&uuml;r den Termin eingeben';
-$lang['error_noupload'] = 'FEHLER: Die hochgeladene Datei nicht gefunden werden';
+$lang['error_noupload'] = 'FEHLER: Es wurde keine hochgeladene Datei gefunden';
 $lang['error_invalidfilename'] = 'FEHLER: Die hochgeladene Datei kann nicht akzeptiert werden';
 $lang['error_problemwithupload'] = 'FEHLER: Beim Hochladen der Datei ist ein Fehler aufgetreten';
 $lang['error_filecopyfailed'] = 'FEHLER: Beim Kopieren der Datei an den Zielort ist ein Fehler aufgetreten';
@@ -251,7 +255,7 @@ $lang['cal_settings_updated'] = 'Einstellungen aktualisiert';
 $lang['cal_add_event'] = 'Termin hinzuf&uuml;gen';
 $lang['cal_edit'] = 'Bearbeiten';
 $lang['cal_delete'] = 'L&ouml;schen';
-$lang['cal_areyousure'] = 'Wollen Sie dies wirklich l&ouml;schen wollen?';
+$lang['cal_areyousure'] = 'Wollen Sie dies wirklich l&ouml;schen?';
 $lang['cal_update_template'] = 'Template aktualisieren';
 $lang['cal_sunday'] = 'Sonntag';
 $lang['cal_monday'] = 'Montag';
@@ -292,24 +296,24 @@ $lang['cal_past_events'] = 'Vergangene Termine';
 $lang['cal_upcoming_events'] = 'Bevorstehende Termine';
 $lang['cal_any_category'] = 'Irgendeiner Kategorie';
 $lang['cal_show_only_events_in'] = 'Nur Termine anzeigen aus';
-$lang['cal_filter_by'] = 'Filtern mit <em>(regex)</em>';
-$lang['cal_go'] = 'Filter anwenden';
+$lang['cal_filter_by'] = 'Titel filtern mit <em>(regex)</em> ';
+$lang['cal_go'] = 'Filtern';
 $lang['cal_title'] = 'Titel';
-$lang['cal_fromdate'] = '&bdquo;von&ldquo;-Datum';
-$lang['cal_todate'] = '&bdquo;bis&ldquo;-Datum';
+$lang['cal_fromdate'] = '&quot;Von&quot;-Datum';
+$lang['cal_todate'] = '&quot;Bis&quot;-Datum';
 $lang['cal_update_categories'] = 'Kategorien aktualisieren';
 $lang['cal_language'] = 'Sprache';
 $lang['cal_updatesettings'] = 'Einstellungen aktualisieren';
-$lang['cal_use_twelve_hour_clock'] = 'In den Listenmen&uuml;-Feldern die 12-Stunden-Anzeige verwenden';
+$lang['cal_use_twelve_hour_clock'] = 'In den Listenmen&uuml;-Feldern die 12-Stunden-Anzeige verwenden?';
 $lang['cal_default_category'] = 'Standard-Kategorie';
 $lang['cal_update_fields'] = 'Felder aktualisieren';
-$lang['force_category'] = 'F&uuml;r den Termin mindestens 1 Kategorie festgelegen';
+$lang['force_category'] = 'F&uuml;r den Termin muss mindestens 1 Kategorie festgelegt werden';
 $lang['showpastyears'] = 'Wieviele Jahre in die Vergangenheit sollen angezeigt werden';
-$lang['showfutureyears'] = 'Wieviel Jahre in die Zukunft sollen angezeigt werden';
+$lang['showfutureyears'] = 'Wieviele Jahre in die Zukunft sollen angezeigt werden';
 $lang['hidesummary'] = 'Die Anzeige des Zusammenfassungsfeldes deaktiveren (nur in der Administration)';
 $lang['hidecontent'] = 'Die Anzeige des Detailfeldes deaktiveren (nur in der Administration)';
 $lang['category_reminder'] = 'Bitte legen Sie eine oder mehrere Kategorien f&uuml;r diesen Termin fest.';
-$lang['module_example_stylesheet'] = 'CSS-Beispiel f&uuml;r den Kalender';
+$lang['module_example_stylesheet'] = 'CSS-Beispiel f&uuml;r Calguys Kalender';
 $lang['error_permission'] = 'Sie ben&ouml;tigen die Berechtigung %s, um diese Funktion nutzen zu k&ouml;nnen.';
 $lang['install_postmessage'] = 'Stellen Sie sicher, dass die Benutzer, die die Termine im Kalender verwalten, die Berechtigung &bdquo;Modify Calendar&ldquo; haben.';
 $lang['deletetagged'] = 'Markierte Termine l&ouml;schen';
@@ -325,20 +329,20 @@ $lang['edittemplate'] = 'Template bearbeiten';
 $lang['deletetemplate'] = 'Template l&ouml;schen';
 $lang['newtemplate'] = 'Neuer Template-Name';
 $lang['templatenameexists'] = 'Fehler: Ein Template mit diesem Namen existiert bereits. Bitte w&auml;hlen Sie einen anderen Namen.';
-$lang['templateimported'] = 'Das Template wurde erfolgreich in die Datenbank importiert und zur weiteren Verwendung installiert.';
+$lang['templateimported'] = 'Das Template wurde erfolgreich in die Datenbank importiert und steht nun zur weiteren Verwendung bereit.';
 $lang['view_default_stylesheet'] = 'Standard-Stylesheet anzeigen';
 $lang['filename'] = 'Dateiname';
 $lang['importtemplate'] = 'Template importieren';
 $lang['template_deleted'] = 'Das Template wurde erfolgreich aus der Datenbank gel&ouml;scht.';
 $lang['updatetemplatesuccess'] = 'Das Template wurde erfolgreich aktualisiert.';
-$lang['updatetemplatefailure'] = 'Beim Aktualisieren des Templates  ist ein Fehler aufgetreten.';
+$lang['updatetemplatefailure'] = 'Beim Aktualisieren des Templates ist ein Fehler aufgetreten.';
 $lang['settingssaved'] = 'Die Einstellungen wurden erfolgreich gespeichert.';
 $lang['categorydeleted'] = 'Kategorie gel&ouml;scht';
 $lang['categoryupdated'] = 'Kategorie aktualisiert';
 $lang['categoryadded'] = 'Kategorie hinzugef&uuml;gt';
 $lang['eventdeleted'] = 'Der Termin wurde gel&ouml;scht.';
 $lang['eventupdated'] = 'Der Termin wurde aktualisiert.';
-$lang['default_page_error'] = 'Fehler: Um das Kalender-Modul mit der Funktion &bdquo;Pretty URL&ldquo; nutzen zu k&ouml;nnen, muss eine Standardseite festgelegt werden. Gehen Sie daf&uuml;r in die Registerkarte &bdquo;Einstellungen&ldquo; und w&auml;hlen dort eine Seite aus.';
+$lang['default_page_error'] = 'FEHLER: Um das Kalender-Modul mit der Funktion &bdquo;Pretty URL&ldquo; nutzen zu k&ouml;nnen, muss eine Standardseite festgelegt werden. Gehen Sie daf&uuml;r in die Registerkarte &bdquo;Einstellungen&ldquo; und w&auml;hlen dort eine Seite aus.';
 $lang['time_at'] = 'am';
 $lang['type'] = 'Typ';
 $lang['name'] = 'Name ';
@@ -348,7 +352,7 @@ $lang['fielddeleted'] = 'Das Feld wurde gel&ouml;scht';
 $lang['fields'] = 'Benutzerdefinierte Felder';
 $lang['textfield'] = 'Textfeld';
 $lang['uploadfield'] = 'Feld zum Hochladen von Datei';
-$lang['description'] = '<p>Das Kalender-Modul dient der Anzeige von Terminen auf Ihrer Webseite. Nach der Installation k&ouml;nnen Sie in der Administration &uuml;ber das Men&uuml; &bdquo;Inhalte > Kalender&ldquo; Ihre Termine/Ereignisse verwalten.</p>';
+$lang['description'] = '<p>Mit dem Kalender-Modul k&ouml;nnen Terminen auf Ihrer Webseite angezeigt werden. Nach der Installation k&ouml;nnen Sie in der Administration &uuml;ber das Men&uuml; &bdquo;Inhalte > Kalender&ldquo; Ihre Termine/Ereignisse verwalten.</p>';
 $lang['defaultcalendarpage'] = 'Standardseite, auf der das Kalender-Modul angezeigt wird. (Diese Seite muss den Smarty-Tag zum Aufruf des Kalender-Moduls enthalten. Wenn Sie die Funktion &bdquo;Pretty URL&ldquo; nutzen wollen, ist diese Einstellung zwingend erforderlich.)';
 $lang['uploaddirectory'] = 'Verzeichnis, in dem die hochgeladenen Dateien abgelegt werden sollen';
 $lang['uploadfiletypes'] = 'Erlaubte Dateitypen';
@@ -363,8 +367,7 @@ $lang['help_template'] = '<p><b>Name des Autors ausgeben:</b></p>
 <code>Autor: {$event.authorname}</code>
 ';
 $lang['cal_help'] = '<h3>Hinweis:</h3>
-<p>Die Version 1.0 des Kalender-Moduls ist nicht kompatibel zu fr&uuml;heren Versionen. Eine Aktualisierung fr&uuml;herer Installationen auf diese Version ist NICHT m&ouml;glich.
-</p>
+<p>Die Version 1.0 von Calguys Kalender ist eine Weiterentwicklung des alten Calender-Moduls. Aufgrund dessen wird es nicht zusammen mit anderen Versionen funktionieren.</p>
 <h3>Was macht dieses Modul?</h3>
 <p>Das Kalender-Modul ist dazu da, um einen Kalender mit Terminen/Ereignissen auf Ihrer Webseite anzuzeigen. Nach der Installation k&ouml;nnen Sie in der Administration &uuml;ber das Men&uuml; &bdquo;Inhalte > Kalender&ldquo; Ihre Termine/Ereignisse verwalten.</p>
 <h3>Sicherheit</h3>
@@ -553,8 +556,8 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
-$lang['qca'] = 'P0-75091478-1268421814072';
-$lang['utmz'] = '156861353.1281851984.41.24.utmcsr=cmsmadesimple.de|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
-$lang['utma'] = '156861353.728989452.1268567475.1281765954.1281851984.41';
+$lang['utma'] = '156861353.1472747146.1287205544.1287205544.1287208226.2';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1287205544.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
