@@ -1,4 +1,11 @@
 <?php
+$lang['dflt_urlprefix'] = 'Standard URL-prefiks for brukervennlige URLer';
+$lang['dflt_alldayevent'] = 'Nye begivenheter er &quot;Hele dagen&quot; begivenheter som standard';
+$lang['dflt_starttime'] = 'Standard starttid for nye begivenheter';
+$lang['info_dflt_starttime'] = '<em>(kun gyldig om nye begivenheter ikke er &quot;Hele dagen&quot; begivenheter.)</em>';
+$lang['search_type'] = 'S&oslash;ketype';
+$lang['search_any'] = 'Vis resultater som passer hvilket som helst ord';
+$lang['search_all'] = 'Vis resultater som passer alle ordene';
 $lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Merk:</span> &quot;Filopplastingsfelt&quot; er ikke s&oslash;kbare.';
 $lang['searchable'] = 'S&oslash;kbar';
 $lang['help_param_editeventtemplate'] = 'Gjelder kun til myevents handlingen, denne parameteren kan angi en ikke standard &#039;rediger begivenhet&#039; mal som skal brukes n&aring;r en bruker oppretter eller redigerer en begivenhet';
@@ -389,8 +396,9 @@ in order to add, edit, or delete calendar event entries.</p>
      <td>action</td>
      <td>Acceptable values:<br>
         &quot;default&quot; - Specifies the default action, works in conjunction with the &quot;display&quot; parameter below.<br/>
-	&quot;search&quot; - Display a form for advanced searching of calendar events.
-        &quot;myevents&quot; - Display a list of all of a users events, and allow adding, editing or deleting those events&quot;;
+	&quot;search&quot; - Display a form for advanced searching of calendar events.<br/>
+        &quot;myevents&quot; - Display a list of all of a users events, and allow adding, editing or deleting those events<br/>
+        &quot;addedit_event&quot; - Display a form allowing to add or edit a single event.;
      </td>
   </tr>
 
@@ -541,9 +549,9 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
-$lang['utmz'] = '156861353.1279922282.3039.70.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1280071165.1280081509.3052';
+$lang['utmz'] = '156861353.1283287349.3202.74.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1284228895.1284233799.3248';
 $lang['qca'] = '1210971690-27308073-81952832';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1280081509';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
